@@ -1,5 +1,5 @@
-(defproject clj-stacktrace "0.2.6"
+(defproject clj-stacktrace "0.2.7"
   :description "More readable stacktraces in Clojure programs."
-  :url "http://github.com/mmcgrana/clj-stacktrace"
+  :url "https://github.com/mmcgrana/clj-stacktrace"
   :license {:name "MIT" :url "http://opensource.org/licenses/MIT"}
   :dependencies [[org.clojure/clojure "1.4.0"]])
